#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_snmp(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def snmp_server_context_context_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        context = ET.SubElement(snmp_server, "context")
        context_name = ET.SubElement(context, "context-name")
        context_name.text = kwargs.pop('context_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_context_vrf_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        context = ET.SubElement(snmp_server, "context")
        context_name_key = ET.SubElement(context, "context-name")
        context_name_key.text = kwargs.pop('context_name')
        vrf_name = ET.SubElement(context, "vrf-name")
        vrf_name.text = kwargs.pop('vrf_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_community_community(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        community = ET.SubElement(snmp_server, "community")
        community = ET.SubElement(community, "community")
        community.text = kwargs.pop('community')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_community_groupname(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        community = ET.SubElement(snmp_server, "community")
        community_key = ET.SubElement(community, "community")
        community_key.text = kwargs.pop('community')
        groupname = ET.SubElement(community, "groupname")
        groupname.text = kwargs.pop('groupname')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_community_ipv4_acl(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        community = ET.SubElement(snmp_server, "community")
        community_key = ET.SubElement(community, "community")
        community_key.text = kwargs.pop('community')
        ipv4_acl = ET.SubElement(community, "ipv4-acl")
        ipv4_acl.text = kwargs.pop('ipv4_acl')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_community_ipv6_acl(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        community = ET.SubElement(snmp_server, "community")
        community_key = ET.SubElement(community, "community")
        community_key.text = kwargs.pop('community')
        ipv6_acl = ET.SubElement(community, "ipv6-acl")
        ipv6_acl.text = kwargs.pop('ipv6_acl')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_user_username(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        user = ET.SubElement(snmp_server, "user")
        username = ET.SubElement(user, "username")
        username.text = kwargs.pop('username')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_user_groupname(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        user = ET.SubElement(snmp_server, "user")
        username_key = ET.SubElement(user, "username")
        username_key.text = kwargs.pop('username')
        groupname = ET.SubElement(user, "groupname")
        groupname.text = kwargs.pop('groupname')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_user_auth(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        user = ET.SubElement(snmp_server, "user")
        username_key = ET.SubElement(user, "username")
        username_key.text = kwargs.pop('username')
        auth = ET.SubElement(user, "auth")
        auth.text = kwargs.pop('auth')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_user_auth_password(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        user = ET.SubElement(snmp_server, "user")
        username_key = ET.SubElement(user, "username")
        username_key.text = kwargs.pop('username')
        auth_password = ET.SubElement(user, "auth-password")
        auth_password.text = kwargs.pop('auth_password')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_user_priv(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        user = ET.SubElement(snmp_server, "user")
        username_key = ET.SubElement(user, "username")
        username_key.text = kwargs.pop('username')
        priv = ET.SubElement(user, "priv")
        priv.text = kwargs.pop('priv')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_user_priv_password(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        user = ET.SubElement(snmp_server, "user")
        username_key = ET.SubElement(user, "username")
        username_key.text = kwargs.pop('username')
        priv_password = ET.SubElement(user, "priv-password")
        priv_password.text = kwargs.pop('priv_password')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_user_encrypted(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        user = ET.SubElement(snmp_server, "user")
        username_key = ET.SubElement(user, "username")
        username_key.text = kwargs.pop('username')
        encrypted = ET.SubElement(user, "encrypted")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_user_ipv4_acl(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        user = ET.SubElement(snmp_server, "user")
        username_key = ET.SubElement(user, "username")
        username_key.text = kwargs.pop('username')
        ipv4_acl = ET.SubElement(user, "ipv4-acl")
        ipv4_acl.text = kwargs.pop('ipv4_acl')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_user_ipv6_acl(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        user = ET.SubElement(snmp_server, "user")
        username_key = ET.SubElement(user, "username")
        username_key.text = kwargs.pop('username')
        ipv6_acl = ET.SubElement(user, "ipv6-acl")
        ipv6_acl.text = kwargs.pop('ipv6_acl')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_v3host_hostip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        v3host = ET.SubElement(snmp_server, "v3host")
        username_key = ET.SubElement(v3host, "username")
        username_key.text = kwargs.pop('username')
        hostip = ET.SubElement(v3host, "hostip")
        hostip.text = kwargs.pop('hostip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_v3host_username(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        v3host = ET.SubElement(snmp_server, "v3host")
        hostip_key = ET.SubElement(v3host, "hostip")
        hostip_key.text = kwargs.pop('hostip')
        username = ET.SubElement(v3host, "username")
        username.text = kwargs.pop('username')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_v3host_udp_port(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        v3host = ET.SubElement(snmp_server, "v3host")
        hostip_key = ET.SubElement(v3host, "hostip")
        hostip_key.text = kwargs.pop('hostip')
        username_key = ET.SubElement(v3host, "username")
        username_key.text = kwargs.pop('username')
        udp_port = ET.SubElement(v3host, "udp-port")
        udp_port.text = kwargs.pop('udp_port')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_v3host_notifytype(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        v3host = ET.SubElement(snmp_server, "v3host")
        hostip_key = ET.SubElement(v3host, "hostip")
        hostip_key.text = kwargs.pop('hostip')
        username_key = ET.SubElement(v3host, "username")
        username_key.text = kwargs.pop('username')
        notifytype = ET.SubElement(v3host, "notifytype")
        notifytype.text = kwargs.pop('notifytype')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_v3host_engineid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        v3host = ET.SubElement(snmp_server, "v3host")
        hostip_key = ET.SubElement(v3host, "hostip")
        hostip_key.text = kwargs.pop('hostip')
        username_key = ET.SubElement(v3host, "username")
        username_key.text = kwargs.pop('username')
        engineid = ET.SubElement(v3host, "engineid")
        engineid.text = kwargs.pop('engineid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_v3host_severity_level(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        v3host = ET.SubElement(snmp_server, "v3host")
        hostip_key = ET.SubElement(v3host, "hostip")
        hostip_key.text = kwargs.pop('hostip')
        username_key = ET.SubElement(v3host, "username")
        username_key.text = kwargs.pop('username')
        severity_level = ET.SubElement(v3host, "severity-level")
        severity_level.text = kwargs.pop('severity_level')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_v3host_use_vrf(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        v3host = ET.SubElement(snmp_server, "v3host")
        hostip_key = ET.SubElement(v3host, "hostip")
        hostip_key.text = kwargs.pop('hostip')
        username_key = ET.SubElement(v3host, "username")
        username_key.text = kwargs.pop('username')
        use_vrf = ET.SubElement(v3host, "use-vrf")
        use_vrf.text = kwargs.pop('use_vrf')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_v3host_source_interface_source_interface_type_loopback_loopback(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        v3host = ET.SubElement(snmp_server, "v3host")
        hostip_key = ET.SubElement(v3host, "hostip")
        hostip_key.text = kwargs.pop('hostip')
        username_key = ET.SubElement(v3host, "username")
        username_key.text = kwargs.pop('username')
        source_interface = ET.SubElement(v3host, "source-interface")
        source_interface_type = ET.SubElement(source_interface, "source-interface-type")
        loopback = ET.SubElement(source_interface_type, "loopback")
        loopback = ET.SubElement(loopback, "loopback")
        loopback.text = kwargs.pop('loopback')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_v3host_source_interface_source_interface_type_ve_ve(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        v3host = ET.SubElement(snmp_server, "v3host")
        hostip_key = ET.SubElement(v3host, "hostip")
        hostip_key.text = kwargs.pop('hostip')
        username_key = ET.SubElement(v3host, "username")
        username_key.text = kwargs.pop('username')
        source_interface = ET.SubElement(v3host, "source-interface")
        source_interface_type = ET.SubElement(source_interface, "source-interface-type")
        ve = ET.SubElement(source_interface_type, "ve")
        ve = ET.SubElement(ve, "ve")
        ve.text = kwargs.pop('ve')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_host_ip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        host = ET.SubElement(snmp_server, "host")
        community_key = ET.SubElement(host, "community")
        community_key.text = kwargs.pop('community')
        ip = ET.SubElement(host, "ip")
        ip.text = kwargs.pop('ip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_host_version(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        host = ET.SubElement(snmp_server, "host")
        ip_key = ET.SubElement(host, "ip")
        ip_key.text = kwargs.pop('ip')
        community_key = ET.SubElement(host, "community")
        community_key.text = kwargs.pop('community')
        version = ET.SubElement(host, "version")
        version.text = kwargs.pop('version')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_host_community(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        host = ET.SubElement(snmp_server, "host")
        ip_key = ET.SubElement(host, "ip")
        ip_key.text = kwargs.pop('ip')
        community = ET.SubElement(host, "community")
        community.text = kwargs.pop('community')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_host_udp_port(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        host = ET.SubElement(snmp_server, "host")
        ip_key = ET.SubElement(host, "ip")
        ip_key.text = kwargs.pop('ip')
        community_key = ET.SubElement(host, "community")
        community_key.text = kwargs.pop('community')
        udp_port = ET.SubElement(host, "udp-port")
        udp_port.text = kwargs.pop('udp_port')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_host_severity_level(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        host = ET.SubElement(snmp_server, "host")
        ip_key = ET.SubElement(host, "ip")
        ip_key.text = kwargs.pop('ip')
        community_key = ET.SubElement(host, "community")
        community_key.text = kwargs.pop('community')
        severity_level = ET.SubElement(host, "severity-level")
        severity_level.text = kwargs.pop('severity_level')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_host_use_vrf(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        host = ET.SubElement(snmp_server, "host")
        ip_key = ET.SubElement(host, "ip")
        ip_key.text = kwargs.pop('ip')
        community_key = ET.SubElement(host, "community")
        community_key.text = kwargs.pop('community')
        use_vrf = ET.SubElement(host, "use-vrf")
        use_vrf.text = kwargs.pop('use_vrf')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_host_source_interface_source_interface_type_loopback_loopback(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        host = ET.SubElement(snmp_server, "host")
        ip_key = ET.SubElement(host, "ip")
        ip_key.text = kwargs.pop('ip')
        community_key = ET.SubElement(host, "community")
        community_key.text = kwargs.pop('community')
        source_interface = ET.SubElement(host, "source-interface")
        source_interface_type = ET.SubElement(source_interface, "source-interface-type")
        loopback = ET.SubElement(source_interface_type, "loopback")
        loopback = ET.SubElement(loopback, "loopback")
        loopback.text = kwargs.pop('loopback')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_host_source_interface_source_interface_type_ve_ve(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        host = ET.SubElement(snmp_server, "host")
        ip_key = ET.SubElement(host, "ip")
        ip_key.text = kwargs.pop('ip')
        community_key = ET.SubElement(host, "community")
        community_key.text = kwargs.pop('community')
        source_interface = ET.SubElement(host, "source-interface")
        source_interface_type = ET.SubElement(source_interface, "source-interface-type")
        ve = ET.SubElement(source_interface_type, "ve")
        ve = ET.SubElement(ve, "ve")
        ve.text = kwargs.pop('ve')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_agtconfig_contact(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        agtconfig = ET.SubElement(snmp_server, "agtconfig")
        contact = ET.SubElement(agtconfig, "contact")
        contact.text = kwargs.pop('contact')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_agtconfig_location(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        agtconfig = ET.SubElement(snmp_server, "agtconfig")
        location = ET.SubElement(agtconfig, "location")
        location.text = kwargs.pop('location')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_agtconfig_sys_descr(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        agtconfig = ET.SubElement(snmp_server, "agtconfig")
        sys_descr = ET.SubElement(agtconfig, "sys-descr")
        sys_descr.text = kwargs.pop('sys_descr')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_enable_trap_trap_flag(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        enable = ET.SubElement(snmp_server, "enable")
        trap = ET.SubElement(enable, "trap")
        trap_flag = ET.SubElement(trap, "trap-flag")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_engineID_drop_engineID_local(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        engineID_drop = ET.SubElement(snmp_server, "engineID-drop")
        engineID = ET.SubElement(engineID_drop, "engineID")
        local = ET.SubElement(engineID, "local")
        local.text = kwargs.pop('local')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_view_viewname(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        view = ET.SubElement(snmp_server, "view")
        mibtree_key = ET.SubElement(view, "mibtree")
        mibtree_key.text = kwargs.pop('mibtree')
        viewname = ET.SubElement(view, "viewname")
        viewname.text = kwargs.pop('viewname')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_view_mibtree(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        view = ET.SubElement(snmp_server, "view")
        viewname_key = ET.SubElement(view, "viewname")
        viewname_key.text = kwargs.pop('viewname')
        mibtree = ET.SubElement(view, "mibtree")
        mibtree.text = kwargs.pop('mibtree')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_view_mibtree_access(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        view = ET.SubElement(snmp_server, "view")
        viewname_key = ET.SubElement(view, "viewname")
        viewname_key.text = kwargs.pop('viewname')
        mibtree_key = ET.SubElement(view, "mibtree")
        mibtree_key.text = kwargs.pop('mibtree')
        mibtree_access = ET.SubElement(view, "mibtree-access")
        mibtree_access.text = kwargs.pop('mibtree_access')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_group_group_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        group = ET.SubElement(snmp_server, "group")
        group_version_key = ET.SubElement(group, "group-version")
        group_version_key.text = kwargs.pop('group_version')
        group_name = ET.SubElement(group, "group-name")
        group_name.text = kwargs.pop('group_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_group_group_version(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        group = ET.SubElement(snmp_server, "group")
        group_name_key = ET.SubElement(group, "group-name")
        group_name_key.text = kwargs.pop('group_name')
        group_version = ET.SubElement(group, "group-version")
        group_version.text = kwargs.pop('group_version')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_group_group_auth_mode(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        group = ET.SubElement(snmp_server, "group")
        group_name_key = ET.SubElement(group, "group-name")
        group_name_key.text = kwargs.pop('group_name')
        group_version_key = ET.SubElement(group, "group-version")
        group_version_key.text = kwargs.pop('group_version')
        group_auth_mode = ET.SubElement(group, "group-auth-mode")
        group_auth_mode.text = kwargs.pop('group_auth_mode')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_group_read(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        group = ET.SubElement(snmp_server, "group")
        group_name_key = ET.SubElement(group, "group-name")
        group_name_key.text = kwargs.pop('group_name')
        group_version_key = ET.SubElement(group, "group-version")
        group_version_key.text = kwargs.pop('group_version')
        read = ET.SubElement(group, "read")
        read.text = kwargs.pop('read')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_group_write(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        group = ET.SubElement(snmp_server, "group")
        group_name_key = ET.SubElement(group, "group-name")
        group_name_key.text = kwargs.pop('group_name')
        group_version_key = ET.SubElement(group, "group-version")
        group_version_key.text = kwargs.pop('group_version')
        write = ET.SubElement(group, "write")
        write.text = kwargs.pop('write')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_group_notify(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        group = ET.SubElement(snmp_server, "group")
        group_name_key = ET.SubElement(group, "group-name")
        group_name_key.text = kwargs.pop('group_name')
        group_version_key = ET.SubElement(group, "group-version")
        group_version_key.text = kwargs.pop('group_version')
        notify = ET.SubElement(group, "notify")
        notify.text = kwargs.pop('notify')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_mib_community_map_community(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        mib = ET.SubElement(snmp_server, "mib")
        community_map = ET.SubElement(mib, "community-map")
        community = ET.SubElement(community_map, "community")
        community.text = kwargs.pop('community')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_mib_community_map_context(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        mib = ET.SubElement(snmp_server, "mib")
        community_map = ET.SubElement(mib, "community-map")
        community_key = ET.SubElement(community_map, "community")
        community_key.text = kwargs.pop('community')
        context = ET.SubElement(community_map, "context")
        context.text = kwargs.pop('context')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_context_context_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        context = ET.SubElement(snmp_server, "context")
        context_name = ET.SubElement(context, "context-name")
        context_name.text = kwargs.pop('context_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_context_vrf_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        context = ET.SubElement(snmp_server, "context")
        context_name_key = ET.SubElement(context, "context-name")
        context_name_key.text = kwargs.pop('context_name')
        vrf_name = ET.SubElement(context, "vrf-name")
        vrf_name.text = kwargs.pop('vrf_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_community_community(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        community = ET.SubElement(snmp_server, "community")
        community = ET.SubElement(community, "community")
        community.text = kwargs.pop('community')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_community_groupname(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        community = ET.SubElement(snmp_server, "community")
        community_key = ET.SubElement(community, "community")
        community_key.text = kwargs.pop('community')
        groupname = ET.SubElement(community, "groupname")
        groupname.text = kwargs.pop('groupname')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_community_ipv4_acl(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        community = ET.SubElement(snmp_server, "community")
        community_key = ET.SubElement(community, "community")
        community_key.text = kwargs.pop('community')
        ipv4_acl = ET.SubElement(community, "ipv4-acl")
        ipv4_acl.text = kwargs.pop('ipv4_acl')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_community_ipv6_acl(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        community = ET.SubElement(snmp_server, "community")
        community_key = ET.SubElement(community, "community")
        community_key.text = kwargs.pop('community')
        ipv6_acl = ET.SubElement(community, "ipv6-acl")
        ipv6_acl.text = kwargs.pop('ipv6_acl')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_user_username(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        user = ET.SubElement(snmp_server, "user")
        username = ET.SubElement(user, "username")
        username.text = kwargs.pop('username')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_user_groupname(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        user = ET.SubElement(snmp_server, "user")
        username_key = ET.SubElement(user, "username")
        username_key.text = kwargs.pop('username')
        groupname = ET.SubElement(user, "groupname")
        groupname.text = kwargs.pop('groupname')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_user_auth(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        user = ET.SubElement(snmp_server, "user")
        username_key = ET.SubElement(user, "username")
        username_key.text = kwargs.pop('username')
        auth = ET.SubElement(user, "auth")
        auth.text = kwargs.pop('auth')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_user_auth_password(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        user = ET.SubElement(snmp_server, "user")
        username_key = ET.SubElement(user, "username")
        username_key.text = kwargs.pop('username')
        auth_password = ET.SubElement(user, "auth-password")
        auth_password.text = kwargs.pop('auth_password')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_user_priv(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        user = ET.SubElement(snmp_server, "user")
        username_key = ET.SubElement(user, "username")
        username_key.text = kwargs.pop('username')
        priv = ET.SubElement(user, "priv")
        priv.text = kwargs.pop('priv')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_user_priv_password(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        user = ET.SubElement(snmp_server, "user")
        username_key = ET.SubElement(user, "username")
        username_key.text = kwargs.pop('username')
        priv_password = ET.SubElement(user, "priv-password")
        priv_password.text = kwargs.pop('priv_password')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_user_encrypted(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        user = ET.SubElement(snmp_server, "user")
        username_key = ET.SubElement(user, "username")
        username_key.text = kwargs.pop('username')
        encrypted = ET.SubElement(user, "encrypted")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_user_ipv4_acl(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        user = ET.SubElement(snmp_server, "user")
        username_key = ET.SubElement(user, "username")
        username_key.text = kwargs.pop('username')
        ipv4_acl = ET.SubElement(user, "ipv4-acl")
        ipv4_acl.text = kwargs.pop('ipv4_acl')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_user_ipv6_acl(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        user = ET.SubElement(snmp_server, "user")
        username_key = ET.SubElement(user, "username")
        username_key.text = kwargs.pop('username')
        ipv6_acl = ET.SubElement(user, "ipv6-acl")
        ipv6_acl.text = kwargs.pop('ipv6_acl')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_v3host_hostip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        v3host = ET.SubElement(snmp_server, "v3host")
        username_key = ET.SubElement(v3host, "username")
        username_key.text = kwargs.pop('username')
        hostip = ET.SubElement(v3host, "hostip")
        hostip.text = kwargs.pop('hostip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_v3host_username(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        v3host = ET.SubElement(snmp_server, "v3host")
        hostip_key = ET.SubElement(v3host, "hostip")
        hostip_key.text = kwargs.pop('hostip')
        username = ET.SubElement(v3host, "username")
        username.text = kwargs.pop('username')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_v3host_udp_port(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        v3host = ET.SubElement(snmp_server, "v3host")
        hostip_key = ET.SubElement(v3host, "hostip")
        hostip_key.text = kwargs.pop('hostip')
        username_key = ET.SubElement(v3host, "username")
        username_key.text = kwargs.pop('username')
        udp_port = ET.SubElement(v3host, "udp-port")
        udp_port.text = kwargs.pop('udp_port')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_v3host_notifytype(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        v3host = ET.SubElement(snmp_server, "v3host")
        hostip_key = ET.SubElement(v3host, "hostip")
        hostip_key.text = kwargs.pop('hostip')
        username_key = ET.SubElement(v3host, "username")
        username_key.text = kwargs.pop('username')
        notifytype = ET.SubElement(v3host, "notifytype")
        notifytype.text = kwargs.pop('notifytype')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_v3host_engineid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        v3host = ET.SubElement(snmp_server, "v3host")
        hostip_key = ET.SubElement(v3host, "hostip")
        hostip_key.text = kwargs.pop('hostip')
        username_key = ET.SubElement(v3host, "username")
        username_key.text = kwargs.pop('username')
        engineid = ET.SubElement(v3host, "engineid")
        engineid.text = kwargs.pop('engineid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_v3host_severity_level(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        v3host = ET.SubElement(snmp_server, "v3host")
        hostip_key = ET.SubElement(v3host, "hostip")
        hostip_key.text = kwargs.pop('hostip')
        username_key = ET.SubElement(v3host, "username")
        username_key.text = kwargs.pop('username')
        severity_level = ET.SubElement(v3host, "severity-level")
        severity_level.text = kwargs.pop('severity_level')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_v3host_use_vrf(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        v3host = ET.SubElement(snmp_server, "v3host")
        hostip_key = ET.SubElement(v3host, "hostip")
        hostip_key.text = kwargs.pop('hostip')
        username_key = ET.SubElement(v3host, "username")
        username_key.text = kwargs.pop('username')
        use_vrf = ET.SubElement(v3host, "use-vrf")
        use_vrf.text = kwargs.pop('use_vrf')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_v3host_source_interface_source_interface_type_loopback_loopback(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        v3host = ET.SubElement(snmp_server, "v3host")
        hostip_key = ET.SubElement(v3host, "hostip")
        hostip_key.text = kwargs.pop('hostip')
        username_key = ET.SubElement(v3host, "username")
        username_key.text = kwargs.pop('username')
        source_interface = ET.SubElement(v3host, "source-interface")
        source_interface_type = ET.SubElement(source_interface, "source-interface-type")
        loopback = ET.SubElement(source_interface_type, "loopback")
        loopback = ET.SubElement(loopback, "loopback")
        loopback.text = kwargs.pop('loopback')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_v3host_source_interface_source_interface_type_ve_ve(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        v3host = ET.SubElement(snmp_server, "v3host")
        hostip_key = ET.SubElement(v3host, "hostip")
        hostip_key.text = kwargs.pop('hostip')
        username_key = ET.SubElement(v3host, "username")
        username_key.text = kwargs.pop('username')
        source_interface = ET.SubElement(v3host, "source-interface")
        source_interface_type = ET.SubElement(source_interface, "source-interface-type")
        ve = ET.SubElement(source_interface_type, "ve")
        ve = ET.SubElement(ve, "ve")
        ve.text = kwargs.pop('ve')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_host_ip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        host = ET.SubElement(snmp_server, "host")
        community_key = ET.SubElement(host, "community")
        community_key.text = kwargs.pop('community')
        ip = ET.SubElement(host, "ip")
        ip.text = kwargs.pop('ip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_host_version(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        host = ET.SubElement(snmp_server, "host")
        ip_key = ET.SubElement(host, "ip")
        ip_key.text = kwargs.pop('ip')
        community_key = ET.SubElement(host, "community")
        community_key.text = kwargs.pop('community')
        version = ET.SubElement(host, "version")
        version.text = kwargs.pop('version')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_host_community(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        host = ET.SubElement(snmp_server, "host")
        ip_key = ET.SubElement(host, "ip")
        ip_key.text = kwargs.pop('ip')
        community = ET.SubElement(host, "community")
        community.text = kwargs.pop('community')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_host_udp_port(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        host = ET.SubElement(snmp_server, "host")
        ip_key = ET.SubElement(host, "ip")
        ip_key.text = kwargs.pop('ip')
        community_key = ET.SubElement(host, "community")
        community_key.text = kwargs.pop('community')
        udp_port = ET.SubElement(host, "udp-port")
        udp_port.text = kwargs.pop('udp_port')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_host_severity_level(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        host = ET.SubElement(snmp_server, "host")
        ip_key = ET.SubElement(host, "ip")
        ip_key.text = kwargs.pop('ip')
        community_key = ET.SubElement(host, "community")
        community_key.text = kwargs.pop('community')
        severity_level = ET.SubElement(host, "severity-level")
        severity_level.text = kwargs.pop('severity_level')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_host_use_vrf(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        host = ET.SubElement(snmp_server, "host")
        ip_key = ET.SubElement(host, "ip")
        ip_key.text = kwargs.pop('ip')
        community_key = ET.SubElement(host, "community")
        community_key.text = kwargs.pop('community')
        use_vrf = ET.SubElement(host, "use-vrf")
        use_vrf.text = kwargs.pop('use_vrf')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_host_source_interface_source_interface_type_loopback_loopback(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        host = ET.SubElement(snmp_server, "host")
        ip_key = ET.SubElement(host, "ip")
        ip_key.text = kwargs.pop('ip')
        community_key = ET.SubElement(host, "community")
        community_key.text = kwargs.pop('community')
        source_interface = ET.SubElement(host, "source-interface")
        source_interface_type = ET.SubElement(source_interface, "source-interface-type")
        loopback = ET.SubElement(source_interface_type, "loopback")
        loopback = ET.SubElement(loopback, "loopback")
        loopback.text = kwargs.pop('loopback')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_host_source_interface_source_interface_type_ve_ve(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        host = ET.SubElement(snmp_server, "host")
        ip_key = ET.SubElement(host, "ip")
        ip_key.text = kwargs.pop('ip')
        community_key = ET.SubElement(host, "community")
        community_key.text = kwargs.pop('community')
        source_interface = ET.SubElement(host, "source-interface")
        source_interface_type = ET.SubElement(source_interface, "source-interface-type")
        ve = ET.SubElement(source_interface_type, "ve")
        ve = ET.SubElement(ve, "ve")
        ve.text = kwargs.pop('ve')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_agtconfig_contact(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        agtconfig = ET.SubElement(snmp_server, "agtconfig")
        contact = ET.SubElement(agtconfig, "contact")
        contact.text = kwargs.pop('contact')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_agtconfig_location(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        agtconfig = ET.SubElement(snmp_server, "agtconfig")
        location = ET.SubElement(agtconfig, "location")
        location.text = kwargs.pop('location')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_agtconfig_sys_descr(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        agtconfig = ET.SubElement(snmp_server, "agtconfig")
        sys_descr = ET.SubElement(agtconfig, "sys-descr")
        sys_descr.text = kwargs.pop('sys_descr')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_enable_trap_trap_flag(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        enable = ET.SubElement(snmp_server, "enable")
        trap = ET.SubElement(enable, "trap")
        trap_flag = ET.SubElement(trap, "trap-flag")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_engineID_drop_engineID_local(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        engineID_drop = ET.SubElement(snmp_server, "engineID-drop")
        engineID = ET.SubElement(engineID_drop, "engineID")
        local = ET.SubElement(engineID, "local")
        local.text = kwargs.pop('local')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_view_viewname(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        view = ET.SubElement(snmp_server, "view")
        mibtree_key = ET.SubElement(view, "mibtree")
        mibtree_key.text = kwargs.pop('mibtree')
        viewname = ET.SubElement(view, "viewname")
        viewname.text = kwargs.pop('viewname')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_view_mibtree(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        view = ET.SubElement(snmp_server, "view")
        viewname_key = ET.SubElement(view, "viewname")
        viewname_key.text = kwargs.pop('viewname')
        mibtree = ET.SubElement(view, "mibtree")
        mibtree.text = kwargs.pop('mibtree')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_view_mibtree_access(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        view = ET.SubElement(snmp_server, "view")
        viewname_key = ET.SubElement(view, "viewname")
        viewname_key.text = kwargs.pop('viewname')
        mibtree_key = ET.SubElement(view, "mibtree")
        mibtree_key.text = kwargs.pop('mibtree')
        mibtree_access = ET.SubElement(view, "mibtree-access")
        mibtree_access.text = kwargs.pop('mibtree_access')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_group_group_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        group = ET.SubElement(snmp_server, "group")
        group_version_key = ET.SubElement(group, "group-version")
        group_version_key.text = kwargs.pop('group_version')
        group_name = ET.SubElement(group, "group-name")
        group_name.text = kwargs.pop('group_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_group_group_version(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        group = ET.SubElement(snmp_server, "group")
        group_name_key = ET.SubElement(group, "group-name")
        group_name_key.text = kwargs.pop('group_name')
        group_version = ET.SubElement(group, "group-version")
        group_version.text = kwargs.pop('group_version')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_group_group_auth_mode(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        group = ET.SubElement(snmp_server, "group")
        group_name_key = ET.SubElement(group, "group-name")
        group_name_key.text = kwargs.pop('group_name')
        group_version_key = ET.SubElement(group, "group-version")
        group_version_key.text = kwargs.pop('group_version')
        group_auth_mode = ET.SubElement(group, "group-auth-mode")
        group_auth_mode.text = kwargs.pop('group_auth_mode')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_group_read(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        group = ET.SubElement(snmp_server, "group")
        group_name_key = ET.SubElement(group, "group-name")
        group_name_key.text = kwargs.pop('group_name')
        group_version_key = ET.SubElement(group, "group-version")
        group_version_key.text = kwargs.pop('group_version')
        read = ET.SubElement(group, "read")
        read.text = kwargs.pop('read')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_group_write(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        group = ET.SubElement(snmp_server, "group")
        group_name_key = ET.SubElement(group, "group-name")
        group_name_key.text = kwargs.pop('group_name')
        group_version_key = ET.SubElement(group, "group-version")
        group_version_key.text = kwargs.pop('group_version')
        write = ET.SubElement(group, "write")
        write.text = kwargs.pop('write')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_group_notify(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        group = ET.SubElement(snmp_server, "group")
        group_name_key = ET.SubElement(group, "group-name")
        group_name_key.text = kwargs.pop('group_name')
        group_version_key = ET.SubElement(group, "group-version")
        group_version_key.text = kwargs.pop('group_version')
        notify = ET.SubElement(group, "notify")
        notify.text = kwargs.pop('notify')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_mib_community_map_community(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        mib = ET.SubElement(snmp_server, "mib")
        community_map = ET.SubElement(mib, "community-map")
        community = ET.SubElement(community_map, "community")
        community.text = kwargs.pop('community')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def snmp_server_mib_community_map_context(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        snmp_server = ET.SubElement(config, "snmp-server", xmlns="urn:brocade.com:mgmt:brocade-snmp")
        mib = ET.SubElement(snmp_server, "mib")
        community_map = ET.SubElement(mib, "community-map")
        community_key = ET.SubElement(community_map, "community")
        community_key.text = kwargs.pop('community')
        context = ET.SubElement(community_map, "context")
        context.text = kwargs.pop('context')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_http_redirect(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def set_http_application_url_input_config_http_app_url_url(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        set_http_application_url = ET.Element("set_http_application_url")
        config = set_http_application_url
        input = ET.SubElement(set_http_application_url, "input")
        config_http_app_url = ET.SubElement(input, "config-http-app-url")
        url = ET.SubElement(config_http_app_url, "url")
        url.text = kwargs.pop('url')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def set_http_application_url_input_config_http_app_url_op_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        set_http_application_url = ET.Element("set_http_application_url")
        config = set_http_application_url
        input = ET.SubElement(set_http_application_url, "input")
        config_http_app_url = ET.SubElement(input, "config-http-app-url")
        op_type = ET.SubElement(config_http_app_url, "op-type")
        op_type.text = kwargs.pop('op_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def set_http_application_url_output_status_code(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        set_http_application_url = ET.Element("set_http_application_url")
        config = set_http_application_url
        output = ET.SubElement(set_http_application_url, "output")
        status_code = ET.SubElement(output, "status-code")
        status_code.text = kwargs.pop('status_code')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def set_http_application_url_output_status_string(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        set_http_application_url = ET.Element("set_http_application_url")
        config = set_http_application_url
        output = ET.SubElement(set_http_application_url, "output")
        status_string = ET.SubElement(output, "status-string")
        status_string.text = kwargs.pop('status_string')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def set_http_application_url_input_config_http_app_url_url(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        set_http_application_url = ET.Element("set_http_application_url")
        config = set_http_application_url
        input = ET.SubElement(set_http_application_url, "input")
        config_http_app_url = ET.SubElement(input, "config-http-app-url")
        url = ET.SubElement(config_http_app_url, "url")
        url.text = kwargs.pop('url')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def set_http_application_url_input_config_http_app_url_op_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        set_http_application_url = ET.Element("set_http_application_url")
        config = set_http_application_url
        input = ET.SubElement(set_http_application_url, "input")
        config_http_app_url = ET.SubElement(input, "config-http-app-url")
        op_type = ET.SubElement(config_http_app_url, "op-type")
        op_type.text = kwargs.pop('op_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def set_http_application_url_output_status_code(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        set_http_application_url = ET.Element("set_http_application_url")
        config = set_http_application_url
        output = ET.SubElement(set_http_application_url, "output")
        status_code = ET.SubElement(output, "status-code")
        status_code.text = kwargs.pop('status_code')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def set_http_application_url_output_status_string(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        set_http_application_url = ET.Element("set_http_application_url")
        config = set_http_application_url
        output = ET.SubElement(set_http_application_url, "output")
        status_string = ET.SubElement(output, "status-string")
        status_string.text = kwargs.pop('status_string')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_mac_address_table(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def mac_address_table_static_mac_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac_address_table = ET.SubElement(config, "mac-address-table", xmlns="urn:brocade.com:mgmt:brocade-mac-address-table")
        static = ET.SubElement(mac_address_table, "static")
        forward_key = ET.SubElement(static, "forward")
        forward_key.text = kwargs.pop('forward')
        interface_type_key = ET.SubElement(static, "interface-type")
        interface_type_key.text = kwargs.pop('interface_type')
        interface_name_key = ET.SubElement(static, "interface-name")
        interface_name_key.text = kwargs.pop('interface_name')
        vlan_key = ET.SubElement(static, "vlan")
        vlan_key.text = kwargs.pop('vlan')
        vlanid_key = ET.SubElement(static, "vlanid")
        vlanid_key.text = kwargs.pop('vlanid')
        mac_address = ET.SubElement(static, "mac-address")
        mac_address.text = kwargs.pop('mac_address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_address_table_static_forward(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac_address_table = ET.SubElement(config, "mac-address-table", xmlns="urn:brocade.com:mgmt:brocade-mac-address-table")
        static = ET.SubElement(mac_address_table, "static")
        mac_address_key = ET.SubElement(static, "mac-address")
        mac_address_key.text = kwargs.pop('mac_address')
        interface_type_key = ET.SubElement(static, "interface-type")
        interface_type_key.text = kwargs.pop('interface_type')
        interface_name_key = ET.SubElement(static, "interface-name")
        interface_name_key.text = kwargs.pop('interface_name')
        vlan_key = ET.SubElement(static, "vlan")
        vlan_key.text = kwargs.pop('vlan')
        vlanid_key = ET.SubElement(static, "vlanid")
        vlanid_key.text = kwargs.pop('vlanid')
        forward = ET.SubElement(static, "forward")
        forward.text = kwargs.pop('forward')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_address_table_static_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac_address_table = ET.SubElement(config, "mac-address-table", xmlns="urn:brocade.com:mgmt:brocade-mac-address-table")
        static = ET.SubElement(mac_address_table, "static")
        mac_address_key = ET.SubElement(static, "mac-address")
        mac_address_key.text = kwargs.pop('mac_address')
        forward_key = ET.SubElement(static, "forward")
        forward_key.text = kwargs.pop('forward')
        interface_name_key = ET.SubElement(static, "interface-name")
        interface_name_key.text = kwargs.pop('interface_name')
        vlan_key = ET.SubElement(static, "vlan")
        vlan_key.text = kwargs.pop('vlan')
        vlanid_key = ET.SubElement(static, "vlanid")
        vlanid_key.text = kwargs.pop('vlanid')
        interface_type = ET.SubElement(static, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_address_table_static_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac_address_table = ET.SubElement(config, "mac-address-table", xmlns="urn:brocade.com:mgmt:brocade-mac-address-table")
        static = ET.SubElement(mac_address_table, "static")
        mac_address_key = ET.SubElement(static, "mac-address")
        mac_address_key.text = kwargs.pop('mac_address')
        forward_key = ET.SubElement(static, "forward")
        forward_key.text = kwargs.pop('forward')
        interface_type_key = ET.SubElement(static, "interface-type")
        interface_type_key.text = kwargs.pop('interface_type')
        vlan_key = ET.SubElement(static, "vlan")
        vlan_key.text = kwargs.pop('vlan')
        vlanid_key = ET.SubElement(static, "vlanid")
        vlanid_key.text = kwargs.pop('vlanid')
        interface_name = ET.SubElement(static, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_address_table_static_vlan(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac_address_table = ET.SubElement(config, "mac-address-table", xmlns="urn:brocade.com:mgmt:brocade-mac-address-table")
        static = ET.SubElement(mac_address_table, "static")
        mac_address_key = ET.SubElement(static, "mac-address")
        mac_address_key.text = kwargs.pop('mac_address')
        forward_key = ET.SubElement(static, "forward")
        forward_key.text = kwargs.pop('forward')
        interface_type_key = ET.SubElement(static, "interface-type")
        interface_type_key.text = kwargs.pop('interface_type')
        interface_name_key = ET.SubElement(static, "interface-name")
        interface_name_key.text = kwargs.pop('interface_name')
        vlanid_key = ET.SubElement(static, "vlanid")
        vlanid_key.text = kwargs.pop('vlanid')
        vlan = ET.SubElement(static, "vlan")
        vlan.text = kwargs.pop('vlan')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_address_table_static_vlanid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac_address_table = ET.SubElement(config, "mac-address-table", xmlns="urn:brocade.com:mgmt:brocade-mac-address-table")
        static = ET.SubElement(mac_address_table, "static")
        mac_address_key = ET.SubElement(static, "mac-address")
        mac_address_key.text = kwargs.pop('mac_address')
        forward_key = ET.SubElement(static, "forward")
        forward_key.text = kwargs.pop('forward')
        interface_type_key = ET.SubElement(static, "interface-type")
        interface_type_key.text = kwargs.pop('interface_type')
        interface_name_key = ET.SubElement(static, "interface-name")
        interface_name_key.text = kwargs.pop('interface_name')
        vlan_key = ET.SubElement(static, "vlan")
        vlan_key.text = kwargs.pop('vlan')
        vlanid = ET.SubElement(static, "vlanid")
        vlanid.text = kwargs.pop('vlanid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_address_table_learning_mode(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac_address_table = ET.SubElement(config, "mac-address-table", xmlns="urn:brocade.com:mgmt:brocade-mac-address-table")
        learning_mode = ET.SubElement(mac_address_table, "learning-mode")
        learning_mode.text = kwargs.pop('learning_mode')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_address_table_aging_time_conversational_time_out(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac_address_table = ET.SubElement(config, "mac-address-table", xmlns="urn:brocade.com:mgmt:brocade-mac-address-table")
        aging_time = ET.SubElement(mac_address_table, "aging-time")
        conversational_time_out = ET.SubElement(aging_time, "conversational-time-out")
        conversational_time_out.text = kwargs.pop('conversational_time_out')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_address_table_aging_time_legacy_time_out(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac_address_table = ET.SubElement(config, "mac-address-table", xmlns="urn:brocade.com:mgmt:brocade-mac-address-table")
        aging_time = ET.SubElement(mac_address_table, "aging-time")
        legacy_time_out = ET.SubElement(aging_time, "legacy-time-out")
        legacy_time_out.text = kwargs.pop('legacy_time_out')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_group_mac_group_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac_group = ET.SubElement(config, "mac-group", xmlns="urn:brocade.com:mgmt:brocade-mac-address-table")
        mac_group_id = ET.SubElement(mac_group, "mac-group-id")
        mac_group_id.text = kwargs.pop('mac_group_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_group_mac_group_entry_entry_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac_group = ET.SubElement(config, "mac-group", xmlns="urn:brocade.com:mgmt:brocade-mac-address-table")
        mac_group_id_key = ET.SubElement(mac_group, "mac-group-id")
        mac_group_id_key.text = kwargs.pop('mac_group_id')
        mac_group_entry = ET.SubElement(mac_group, "mac-group-entry")
        entry_address = ET.SubElement(mac_group_entry, "entry-address")
        entry_address.text = kwargs.pop('entry_address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_address_table_input_request_type_get_request_mac_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_address_table = ET.Element("get_mac_address_table")
        config = get_mac_address_table
        input = ET.SubElement(get_mac_address_table, "input")
        request_type = ET.SubElement(input, "request-type")
        get_request = ET.SubElement(request_type, "get-request")
        mac_address = ET.SubElement(get_request, "mac-address")
        mac_address.text = kwargs.pop('mac_address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_address_table_input_request_type_get_next_request_last_mac_address_details_last_mac_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_address_table = ET.Element("get_mac_address_table")
        config = get_mac_address_table
        input = ET.SubElement(get_mac_address_table, "input")
        request_type = ET.SubElement(input, "request-type")
        get_next_request = ET.SubElement(request_type, "get-next-request")
        last_mac_address_details = ET.SubElement(get_next_request, "last-mac-address-details")
        last_mac_address = ET.SubElement(last_mac_address_details, "last-mac-address")
        last_mac_address.text = kwargs.pop('last_mac_address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_address_table_input_request_type_get_next_request_last_mac_address_details_last_vlan_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_address_table = ET.Element("get_mac_address_table")
        config = get_mac_address_table
        input = ET.SubElement(get_mac_address_table, "input")
        request_type = ET.SubElement(input, "request-type")
        get_next_request = ET.SubElement(request_type, "get-next-request")
        last_mac_address_details = ET.SubElement(get_next_request, "last-mac-address-details")
        last_vlan_id = ET.SubElement(last_mac_address_details, "last-vlan-id")
        last_vlan_id.text = kwargs.pop('last_vlan_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_address_table_input_request_type_get_next_request_last_mac_address_details_last_mac_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_address_table = ET.Element("get_mac_address_table")
        config = get_mac_address_table
        input = ET.SubElement(get_mac_address_table, "input")
        request_type = ET.SubElement(input, "request-type")
        get_next_request = ET.SubElement(request_type, "get-next-request")
        last_mac_address_details = ET.SubElement(get_next_request, "last-mac-address-details")
        last_mac_type = ET.SubElement(last_mac_address_details, "last-mac-type")
        last_mac_type.text = kwargs.pop('last_mac_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_address_table_output_mac_address_table_vlanid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_address_table = ET.Element("get_mac_address_table")
        config = get_mac_address_table
        output = ET.SubElement(get_mac_address_table, "output")
        mac_address_table = ET.SubElement(output, "mac-address-table")
        mac_address_key = ET.SubElement(mac_address_table, "mac-address")
        mac_address_key.text = kwargs.pop('mac_address')
        vlanid = ET.SubElement(mac_address_table, "vlanid")
        vlanid.text = kwargs.pop('vlanid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_address_table_output_mac_address_table_mac_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_address_table = ET.Element("get_mac_address_table")
        config = get_mac_address_table
        output = ET.SubElement(get_mac_address_table, "output")
        mac_address_table = ET.SubElement(output, "mac-address-table")
        vlanid_key = ET.SubElement(mac_address_table, "vlanid")
        vlanid_key.text = kwargs.pop('vlanid')
        mac_address = ET.SubElement(mac_address_table, "mac-address")
        mac_address.text = kwargs.pop('mac_address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_address_table_output_mac_address_table_mac_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_address_table = ET.Element("get_mac_address_table")
        config = get_mac_address_table
        output = ET.SubElement(get_mac_address_table, "output")
        mac_address_table = ET.SubElement(output, "mac-address-table")
        vlanid_key = ET.SubElement(mac_address_table, "vlanid")
        vlanid_key.text = kwargs.pop('vlanid')
        mac_address_key = ET.SubElement(mac_address_table, "mac-address")
        mac_address_key.text = kwargs.pop('mac_address')
        mac_type = ET.SubElement(mac_address_table, "mac-type")
        mac_type.text = kwargs.pop('mac_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_address_table_output_mac_address_table_mac_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_address_table = ET.Element("get_mac_address_table")
        config = get_mac_address_table
        output = ET.SubElement(get_mac_address_table, "output")
        mac_address_table = ET.SubElement(output, "mac-address-table")
        vlanid_key = ET.SubElement(mac_address_table, "vlanid")
        vlanid_key.text = kwargs.pop('vlanid')
        mac_address_key = ET.SubElement(mac_address_table, "mac-address")
        mac_address_key.text = kwargs.pop('mac_address')
        mac_state = ET.SubElement(mac_address_table, "mac-state")
        mac_state.text = kwargs.pop('mac_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_address_table_output_mac_address_table_forwarding_interface_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_address_table = ET.Element("get_mac_address_table")
        config = get_mac_address_table
        output = ET.SubElement(get_mac_address_table, "output")
        mac_address_table = ET.SubElement(output, "mac-address-table")
        vlanid_key = ET.SubElement(mac_address_table, "vlanid")
        vlanid_key.text = kwargs.pop('vlanid')
        mac_address_key = ET.SubElement(mac_address_table, "mac-address")
        mac_address_key.text = kwargs.pop('mac_address')
        forwarding_interface = ET.SubElement(mac_address_table, "forwarding-interface")
        interface_type = ET.SubElement(forwarding_interface, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_address_table_output_mac_address_table_forwarding_interface_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_address_table = ET.Element("get_mac_address_table")
        config = get_mac_address_table
        output = ET.SubElement(get_mac_address_table, "output")
        mac_address_table = ET.SubElement(output, "mac-address-table")
        vlanid_key = ET.SubElement(mac_address_table, "vlanid")
        vlanid_key.text = kwargs.pop('vlanid')
        mac_address_key = ET.SubElement(mac_address_table, "mac-address")
        mac_address_key.text = kwargs.pop('mac_address')
        forwarding_interface = ET.SubElement(mac_address_table, "forwarding-interface")
        interface_name = ET.SubElement(forwarding_interface, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_address_table_output_has_more(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_address_table = ET.Element("get_mac_address_table")
        config = get_mac_address_table
        output = ET.SubElement(get_mac_address_table, "output")
        has_more = ET.SubElement(output, "has-more")
        has_more.text = kwargs.pop('has_more')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_address_table_static_mac_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac_address_table = ET.SubElement(config, "mac-address-table", xmlns="urn:brocade.com:mgmt:brocade-mac-address-table")
        static = ET.SubElement(mac_address_table, "static")
        forward_key = ET.SubElement(static, "forward")
        forward_key.text = kwargs.pop('forward')
        interface_type_key = ET.SubElement(static, "interface-type")
        interface_type_key.text = kwargs.pop('interface_type')
        interface_name_key = ET.SubElement(static, "interface-name")
        interface_name_key.text = kwargs.pop('interface_name')
        vlan_key = ET.SubElement(static, "vlan")
        vlan_key.text = kwargs.pop('vlan')
        vlanid_key = ET.SubElement(static, "vlanid")
        vlanid_key.text = kwargs.pop('vlanid')
        mac_address = ET.SubElement(static, "mac-address")
        mac_address.text = kwargs.pop('mac_address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_address_table_static_forward(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac_address_table = ET.SubElement(config, "mac-address-table", xmlns="urn:brocade.com:mgmt:brocade-mac-address-table")
        static = ET.SubElement(mac_address_table, "static")
        mac_address_key = ET.SubElement(static, "mac-address")
        mac_address_key.text = kwargs.pop('mac_address')
        interface_type_key = ET.SubElement(static, "interface-type")
        interface_type_key.text = kwargs.pop('interface_type')
        interface_name_key = ET.SubElement(static, "interface-name")
        interface_name_key.text = kwargs.pop('interface_name')
        vlan_key = ET.SubElement(static, "vlan")
        vlan_key.text = kwargs.pop('vlan')
        vlanid_key = ET.SubElement(static, "vlanid")
        vlanid_key.text = kwargs.pop('vlanid')
        forward = ET.SubElement(static, "forward")
        forward.text = kwargs.pop('forward')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_address_table_static_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac_address_table = ET.SubElement(config, "mac-address-table", xmlns="urn:brocade.com:mgmt:brocade-mac-address-table")
        static = ET.SubElement(mac_address_table, "static")
        mac_address_key = ET.SubElement(static, "mac-address")
        mac_address_key.text = kwargs.pop('mac_address')
        forward_key = ET.SubElement(static, "forward")
        forward_key.text = kwargs.pop('forward')
        interface_name_key = ET.SubElement(static, "interface-name")
        interface_name_key.text = kwargs.pop('interface_name')
        vlan_key = ET.SubElement(static, "vlan")
        vlan_key.text = kwargs.pop('vlan')
        vlanid_key = ET.SubElement(static, "vlanid")
        vlanid_key.text = kwargs.pop('vlanid')
        interface_type = ET.SubElement(static, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_address_table_static_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac_address_table = ET.SubElement(config, "mac-address-table", xmlns="urn:brocade.com:mgmt:brocade-mac-address-table")
        static = ET.SubElement(mac_address_table, "static")
        mac_address_key = ET.SubElement(static, "mac-address")
        mac_address_key.text = kwargs.pop('mac_address')
        forward_key = ET.SubElement(static, "forward")
        forward_key.text = kwargs.pop('forward')
        interface_type_key = ET.SubElement(static, "interface-type")
        interface_type_key.text = kwargs.pop('interface_type')
        vlan_key = ET.SubElement(static, "vlan")
        vlan_key.text = kwargs.pop('vlan')
        vlanid_key = ET.SubElement(static, "vlanid")
        vlanid_key.text = kwargs.pop('vlanid')
        interface_name = ET.SubElement(static, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_address_table_static_vlan(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac_address_table = ET.SubElement(config, "mac-address-table", xmlns="urn:brocade.com:mgmt:brocade-mac-address-table")
        static = ET.SubElement(mac_address_table, "static")
        mac_address_key = ET.SubElement(static, "mac-address")
        mac_address_key.text = kwargs.pop('mac_address')
        forward_key = ET.SubElement(static, "forward")
        forward_key.text = kwargs.pop('forward')
        interface_type_key = ET.SubElement(static, "interface-type")
        interface_type_key.text = kwargs.pop('interface_type')
        interface_name_key = ET.SubElement(static, "interface-name")
        interface_name_key.text = kwargs.pop('interface_name')
        vlanid_key = ET.SubElement(static, "vlanid")
        vlanid_key.text = kwargs.pop('vlanid')
        vlan = ET.SubElement(static, "vlan")
        vlan.text = kwargs.pop('vlan')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_address_table_static_vlanid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac_address_table = ET.SubElement(config, "mac-address-table", xmlns="urn:brocade.com:mgmt:brocade-mac-address-table")
        static = ET.SubElement(mac_address_table, "static")
        mac_address_key = ET.SubElement(static, "mac-address")
        mac_address_key.text = kwargs.pop('mac_address')
        forward_key = ET.SubElement(static, "forward")
        forward_key.text = kwargs.pop('forward')
        interface_type_key = ET.SubElement(static, "interface-type")
        interface_type_key.text = kwargs.pop('interface_type')
        interface_name_key = ET.SubElement(static, "interface-name")
        interface_name_key.text = kwargs.pop('interface_name')
        vlan_key = ET.SubElement(static, "vlan")
        vlan_key.text = kwargs.pop('vlan')
        vlanid = ET.SubElement(static, "vlanid")
        vlanid.text = kwargs.pop('vlanid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_address_table_learning_mode(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac_address_table = ET.SubElement(config, "mac-address-table", xmlns="urn:brocade.com:mgmt:brocade-mac-address-table")
        learning_mode = ET.SubElement(mac_address_table, "learning-mode")
        learning_mode.text = kwargs.pop('learning_mode')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_address_table_aging_time_conversational_time_out(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac_address_table = ET.SubElement(config, "mac-address-table", xmlns="urn:brocade.com:mgmt:brocade-mac-address-table")
        aging_time = ET.SubElement(mac_address_table, "aging-time")
        conversational_time_out = ET.SubElement(aging_time, "conversational-time-out")
        conversational_time_out.text = kwargs.pop('conversational_time_out')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_address_table_aging_time_legacy_time_out(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac_address_table = ET.SubElement(config, "mac-address-table", xmlns="urn:brocade.com:mgmt:brocade-mac-address-table")
        aging_time = ET.SubElement(mac_address_table, "aging-time")
        legacy_time_out = ET.SubElement(aging_time, "legacy-time-out")
        legacy_time_out.text = kwargs.pop('legacy_time_out')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_group_mac_group_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac_group = ET.SubElement(config, "mac-group", xmlns="urn:brocade.com:mgmt:brocade-mac-address-table")
        mac_group_id = ET.SubElement(mac_group, "mac-group-id")
        mac_group_id.text = kwargs.pop('mac_group_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_group_mac_group_entry_entry_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac_group = ET.SubElement(config, "mac-group", xmlns="urn:brocade.com:mgmt:brocade-mac-address-table")
        mac_group_id_key = ET.SubElement(mac_group, "mac-group-id")
        mac_group_id_key.text = kwargs.pop('mac_group_id')
        mac_group_entry = ET.SubElement(mac_group, "mac-group-entry")
        entry_address = ET.SubElement(mac_group_entry, "entry-address")
        entry_address.text = kwargs.pop('entry_address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_address_table_input_request_type_get_request_mac_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_address_table = ET.Element("get_mac_address_table")
        config = get_mac_address_table
        input = ET.SubElement(get_mac_address_table, "input")
        request_type = ET.SubElement(input, "request-type")
        get_request = ET.SubElement(request_type, "get-request")
        mac_address = ET.SubElement(get_request, "mac-address")
        mac_address.text = kwargs.pop('mac_address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_address_table_input_request_type_get_next_request_last_mac_address_details_last_mac_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_address_table = ET.Element("get_mac_address_table")
        config = get_mac_address_table
        input = ET.SubElement(get_mac_address_table, "input")
        request_type = ET.SubElement(input, "request-type")
        get_next_request = ET.SubElement(request_type, "get-next-request")
        last_mac_address_details = ET.SubElement(get_next_request, "last-mac-address-details")
        last_mac_address = ET.SubElement(last_mac_address_details, "last-mac-address")
        last_mac_address.text = kwargs.pop('last_mac_address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_address_table_input_request_type_get_next_request_last_mac_address_details_last_vlan_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_address_table = ET.Element("get_mac_address_table")
        config = get_mac_address_table
        input = ET.SubElement(get_mac_address_table, "input")
        request_type = ET.SubElement(input, "request-type")
        get_next_request = ET.SubElement(request_type, "get-next-request")
        last_mac_address_details = ET.SubElement(get_next_request, "last-mac-address-details")
        last_vlan_id = ET.SubElement(last_mac_address_details, "last-vlan-id")
        last_vlan_id.text = kwargs.pop('last_vlan_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_address_table_input_request_type_get_next_request_last_mac_address_details_last_mac_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_address_table = ET.Element("get_mac_address_table")
        config = get_mac_address_table
        input = ET.SubElement(get_mac_address_table, "input")
        request_type = ET.SubElement(input, "request-type")
        get_next_request = ET.SubElement(request_type, "get-next-request")
        last_mac_address_details = ET.SubElement(get_next_request, "last-mac-address-details")
        last_mac_type = ET.SubElement(last_mac_address_details, "last-mac-type")
        last_mac_type.text = kwargs.pop('last_mac_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_address_table_output_mac_address_table_vlanid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_address_table = ET.Element("get_mac_address_table")
        config = get_mac_address_table
        output = ET.SubElement(get_mac_address_table, "output")
        mac_address_table = ET.SubElement(output, "mac-address-table")
        mac_address_key = ET.SubElement(mac_address_table, "mac-address")
        mac_address_key.text = kwargs.pop('mac_address')
        vlanid = ET.SubElement(mac_address_table, "vlanid")
        vlanid.text = kwargs.pop('vlanid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_address_table_output_mac_address_table_mac_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_address_table = ET.Element("get_mac_address_table")
        config = get_mac_address_table
        output = ET.SubElement(get_mac_address_table, "output")
        mac_address_table = ET.SubElement(output, "mac-address-table")
        vlanid_key = ET.SubElement(mac_address_table, "vlanid")
        vlanid_key.text = kwargs.pop('vlanid')
        mac_address = ET.SubElement(mac_address_table, "mac-address")
        mac_address.text = kwargs.pop('mac_address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_address_table_output_mac_address_table_mac_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_address_table = ET.Element("get_mac_address_table")
        config = get_mac_address_table
        output = ET.SubElement(get_mac_address_table, "output")
        mac_address_table = ET.SubElement(output, "mac-address-table")
        vlanid_key = ET.SubElement(mac_address_table, "vlanid")
        vlanid_key.text = kwargs.pop('vlanid')
        mac_address_key = ET.SubElement(mac_address_table, "mac-address")
        mac_address_key.text = kwargs.pop('mac_address')
        mac_type = ET.SubElement(mac_address_table, "mac-type")
        mac_type.text = kwargs.pop('mac_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_address_table_output_mac_address_table_mac_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_address_table = ET.Element("get_mac_address_table")
        config = get_mac_address_table
        output = ET.SubElement(get_mac_address_table, "output")
        mac_address_table = ET.SubElement(output, "mac-address-table")
        vlanid_key = ET.SubElement(mac_address_table, "vlanid")
        vlanid_key.text = kwargs.pop('vlanid')
        mac_address_key = ET.SubElement(mac_address_table, "mac-address")
        mac_address_key.text = kwargs.pop('mac_address')
        mac_state = ET.SubElement(mac_address_table, "mac-state")
        mac_state.text = kwargs.pop('mac_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_address_table_output_mac_address_table_forwarding_interface_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_address_table = ET.Element("get_mac_address_table")
        config = get_mac_address_table
        output = ET.SubElement(get_mac_address_table, "output")
        mac_address_table = ET.SubElement(output, "mac-address-table")
        vlanid_key = ET.SubElement(mac_address_table, "vlanid")
        vlanid_key.text = kwargs.pop('vlanid')
        mac_address_key = ET.SubElement(mac_address_table, "mac-address")
        mac_address_key.text = kwargs.pop('mac_address')
        forwarding_interface = ET.SubElement(mac_address_table, "forwarding-interface")
        interface_type = ET.SubElement(forwarding_interface, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_address_table_output_mac_address_table_forwarding_interface_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_address_table = ET.Element("get_mac_address_table")
        config = get_mac_address_table
        output = ET.SubElement(get_mac_address_table, "output")
        mac_address_table = ET.SubElement(output, "mac-address-table")
        vlanid_key = ET.SubElement(mac_address_table, "vlanid")
        vlanid_key.text = kwargs.pop('vlanid')
        mac_address_key = ET.SubElement(mac_address_table, "mac-address")
        mac_address_key.text = kwargs.pop('mac_address')
        forwarding_interface = ET.SubElement(mac_address_table, "forwarding-interface")
        interface_name = ET.SubElement(forwarding_interface, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_address_table_output_has_more(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_address_table = ET.Element("get_mac_address_table")
        config = get_mac_address_table
        output = ET.SubElement(get_mac_address_table, "output")
        has_more = ET.SubElement(output, "has-more")
        has_more.text = kwargs.pop('has_more')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_hardware(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def hardware_connector_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        connector = ET.SubElement(hardware, "connector")
        name = ET.SubElement(connector, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_connector_sfp_breakout(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        connector = ET.SubElement(hardware, "connector")
        name_key = ET.SubElement(connector, "name")
        name_key.text = kwargs.pop('name')
        sfp = ET.SubElement(connector, "sfp")
        breakout = ET.SubElement(sfp, "breakout")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_port_group_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        port_group = ET.SubElement(hardware, "port-group")
        name = ET.SubElement(port_group, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_port_group_mode_performance(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        port_group = ET.SubElement(hardware, "port-group")
        name_key = ET.SubElement(port_group, "name")
        name_key.text = kwargs.pop('name')
        mode = ET.SubElement(port_group, "mode")
        performance = ET.SubElement(mode, "performance")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_connector_group_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        connector_group = ET.SubElement(hardware, "connector-group")
        id = ET.SubElement(connector_group, "id")
        id.text = kwargs.pop('id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_connector_group_speed(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        connector_group = ET.SubElement(hardware, "connector-group")
        id_key = ET.SubElement(connector_group, "id")
        id_key.text = kwargs.pop('id')
        speed = ET.SubElement(connector_group, "speed")
        speed.text = kwargs.pop('speed')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_flexport_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        flexport = ET.SubElement(hardware, "flexport")
        id = ET.SubElement(flexport, "id")
        id.text = kwargs.pop('id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_flexport_flexport_type_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        flexport = ET.SubElement(hardware, "flexport")
        id_key = ET.SubElement(flexport, "id")
        id_key.text = kwargs.pop('id')
        flexport_type = ET.SubElement(flexport, "flexport_type")
        type = ET.SubElement(flexport_type, "type")
        type.text = kwargs.pop('type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_flexport_flexport_type_instance(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        flexport = ET.SubElement(hardware, "flexport")
        id_key = ET.SubElement(flexport, "id")
        id_key.text = kwargs.pop('id')
        flexport_type = ET.SubElement(flexport, "flexport_type")
        instance = ET.SubElement(flexport_type, "instance")
        instance.text = kwargs.pop('instance')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_flexport_flexport_type_skip_deconfig(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        flexport = ET.SubElement(hardware, "flexport")
        id_key = ET.SubElement(flexport, "id")
        id_key.text = kwargs.pop('id')
        flexport_type = ET.SubElement(flexport, "flexport_type")
        skip_deconfig = ET.SubElement(flexport_type, "skip_deconfig")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name = ET.SubElement(kap_custom_profile, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_lacp_lacp_hello_interval(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        lacp = ET.SubElement(kap_custom_profile, "lacp")
        lacp_hello_interval = ET.SubElement(lacp, "lacp_hello_interval")
        lacp_hello_interval.text = kwargs.pop('lacp_hello_interval')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_lacp_lacp_num_entry(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        lacp = ET.SubElement(kap_custom_profile, "lacp")
        lacp_num_entry = ET.SubElement(lacp, "lacp_num_entry")
        lacp_num_entry.text = kwargs.pop('lacp_num_entry')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_xstp_xstp_hello_interval(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        xstp = ET.SubElement(kap_custom_profile, "xstp")
        xstp_hello_interval = ET.SubElement(xstp, "xstp_hello_interval")
        xstp_hello_interval.text = kwargs.pop('xstp_hello_interval')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_xstp_xstp_num_entry(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        xstp = ET.SubElement(kap_custom_profile, "xstp")
        xstp_num_entry = ET.SubElement(xstp, "xstp_num_entry")
        xstp_num_entry.text = kwargs.pop('xstp_num_entry')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_rpvst_rpvst_hello_interval(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        rpvst = ET.SubElement(kap_custom_profile, "rpvst")
        rpvst_hello_interval = ET.SubElement(rpvst, "rpvst_hello_interval")
        rpvst_hello_interval.text = kwargs.pop('rpvst_hello_interval')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_rpvst_rpvst_num_entry(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        rpvst = ET.SubElement(kap_custom_profile, "rpvst")
        rpvst_num_entry = ET.SubElement(rpvst, "rpvst_num_entry")
        rpvst_num_entry.text = kwargs.pop('rpvst_num_entry')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_udld_udld_hello_interval(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        udld = ET.SubElement(kap_custom_profile, "udld")
        udld_hello_interval = ET.SubElement(udld, "udld_hello_interval")
        udld_hello_interval.text = kwargs.pop('udld_hello_interval')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_udld_udld_num_entry(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        udld = ET.SubElement(kap_custom_profile, "udld")
        udld_num_entry = ET.SubElement(udld, "udld_num_entry")
        udld_num_entry.text = kwargs.pop('udld_num_entry')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_bfd_vxlan_bfd_vxlan_hello_interval(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        bfd_vxlan = ET.SubElement(kap_custom_profile, "bfd-vxlan")
        bfd_vxlan_hello_interval = ET.SubElement(bfd_vxlan, "bfd_vxlan_hello_interval")
        bfd_vxlan_hello_interval.text = kwargs.pop('bfd_vxlan_hello_interval')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_bfd_vxlan_bfd_vxlan_num_entry(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        bfd_vxlan = ET.SubElement(kap_custom_profile, "bfd-vxlan")
        bfd_vxlan_num_entry = ET.SubElement(bfd_vxlan, "bfd_vxlan_num_entry")
        bfd_vxlan_num_entry.text = kwargs.pop('bfd_vxlan_num_entry')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_bfd_l3_bfd_l3_hello_interval(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        bfd_l3 = ET.SubElement(kap_custom_profile, "bfd-l3")
        bfd_l3_hello_interval = ET.SubElement(bfd_l3, "bfd_l3_hello_interval")
        bfd_l3_hello_interval.text = kwargs.pop('bfd_l3_hello_interval')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_bfd_l3_bfd_l3_num_entry(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        bfd_l3 = ET.SubElement(kap_custom_profile, "bfd-l3")
        bfd_l3_num_entry = ET.SubElement(bfd_l3, "bfd_l3_num_entry")
        bfd_l3_num_entry.text = kwargs.pop('bfd_l3_num_entry')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_fcoe_fcoe_hello_interval(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        fcoe = ET.SubElement(kap_custom_profile, "fcoe")
        fcoe_hello_interval = ET.SubElement(fcoe, "fcoe_hello_interval")
        fcoe_hello_interval.text = kwargs.pop('fcoe_hello_interval')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_fcoe_fcoe_num_entry(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        fcoe = ET.SubElement(kap_custom_profile, "fcoe")
        fcoe_num_entry = ET.SubElement(fcoe, "fcoe_num_entry")
        fcoe_num_entry.text = kwargs.pop('fcoe_num_entry')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_flexports_output_flexport_list_port_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_flexports = ET.Element("get_flexports")
        config = get_flexports
        output = ET.SubElement(get_flexports, "output")
        flexport_list = ET.SubElement(output, "flexport-list")
        port_id = ET.SubElement(flexport_list, "port-id")
        port_id.text = kwargs.pop('port_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_connector_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        connector = ET.SubElement(hardware, "connector")
        name = ET.SubElement(connector, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_connector_sfp_breakout(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        connector = ET.SubElement(hardware, "connector")
        name_key = ET.SubElement(connector, "name")
        name_key.text = kwargs.pop('name')
        sfp = ET.SubElement(connector, "sfp")
        breakout = ET.SubElement(sfp, "breakout")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_port_group_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        port_group = ET.SubElement(hardware, "port-group")
        name = ET.SubElement(port_group, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_port_group_mode_performance(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        port_group = ET.SubElement(hardware, "port-group")
        name_key = ET.SubElement(port_group, "name")
        name_key.text = kwargs.pop('name')
        mode = ET.SubElement(port_group, "mode")
        performance = ET.SubElement(mode, "performance")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_connector_group_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        connector_group = ET.SubElement(hardware, "connector-group")
        id = ET.SubElement(connector_group, "id")
        id.text = kwargs.pop('id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_connector_group_speed(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        connector_group = ET.SubElement(hardware, "connector-group")
        id_key = ET.SubElement(connector_group, "id")
        id_key.text = kwargs.pop('id')
        speed = ET.SubElement(connector_group, "speed")
        speed.text = kwargs.pop('speed')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_flexport_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        flexport = ET.SubElement(hardware, "flexport")
        id = ET.SubElement(flexport, "id")
        id.text = kwargs.pop('id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_flexport_flexport_type_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        flexport = ET.SubElement(hardware, "flexport")
        id_key = ET.SubElement(flexport, "id")
        id_key.text = kwargs.pop('id')
        flexport_type = ET.SubElement(flexport, "flexport_type")
        type = ET.SubElement(flexport_type, "type")
        type.text = kwargs.pop('type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_flexport_flexport_type_instance(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        flexport = ET.SubElement(hardware, "flexport")
        id_key = ET.SubElement(flexport, "id")
        id_key.text = kwargs.pop('id')
        flexport_type = ET.SubElement(flexport, "flexport_type")
        instance = ET.SubElement(flexport_type, "instance")
        instance.text = kwargs.pop('instance')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_flexport_flexport_type_skip_deconfig(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        flexport = ET.SubElement(hardware, "flexport")
        id_key = ET.SubElement(flexport, "id")
        id_key.text = kwargs.pop('id')
        flexport_type = ET.SubElement(flexport, "flexport_type")
        skip_deconfig = ET.SubElement(flexport_type, "skip_deconfig")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name = ET.SubElement(kap_custom_profile, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_lacp_lacp_hello_interval(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        lacp = ET.SubElement(kap_custom_profile, "lacp")
        lacp_hello_interval = ET.SubElement(lacp, "lacp_hello_interval")
        lacp_hello_interval.text = kwargs.pop('lacp_hello_interval')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_lacp_lacp_num_entry(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        lacp = ET.SubElement(kap_custom_profile, "lacp")
        lacp_num_entry = ET.SubElement(lacp, "lacp_num_entry")
        lacp_num_entry.text = kwargs.pop('lacp_num_entry')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_xstp_xstp_hello_interval(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        xstp = ET.SubElement(kap_custom_profile, "xstp")
        xstp_hello_interval = ET.SubElement(xstp, "xstp_hello_interval")
        xstp_hello_interval.text = kwargs.pop('xstp_hello_interval')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_xstp_xstp_num_entry(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        xstp = ET.SubElement(kap_custom_profile, "xstp")
        xstp_num_entry = ET.SubElement(xstp, "xstp_num_entry")
        xstp_num_entry.text = kwargs.pop('xstp_num_entry')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_rpvst_rpvst_hello_interval(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        rpvst = ET.SubElement(kap_custom_profile, "rpvst")
        rpvst_hello_interval = ET.SubElement(rpvst, "rpvst_hello_interval")
        rpvst_hello_interval.text = kwargs.pop('rpvst_hello_interval')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_rpvst_rpvst_num_entry(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        rpvst = ET.SubElement(kap_custom_profile, "rpvst")
        rpvst_num_entry = ET.SubElement(rpvst, "rpvst_num_entry")
        rpvst_num_entry.text = kwargs.pop('rpvst_num_entry')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_udld_udld_hello_interval(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        udld = ET.SubElement(kap_custom_profile, "udld")
        udld_hello_interval = ET.SubElement(udld, "udld_hello_interval")
        udld_hello_interval.text = kwargs.pop('udld_hello_interval')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_udld_udld_num_entry(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        udld = ET.SubElement(kap_custom_profile, "udld")
        udld_num_entry = ET.SubElement(udld, "udld_num_entry")
        udld_num_entry.text = kwargs.pop('udld_num_entry')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_bfd_vxlan_bfd_vxlan_hello_interval(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        bfd_vxlan = ET.SubElement(kap_custom_profile, "bfd-vxlan")
        bfd_vxlan_hello_interval = ET.SubElement(bfd_vxlan, "bfd_vxlan_hello_interval")
        bfd_vxlan_hello_interval.text = kwargs.pop('bfd_vxlan_hello_interval')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_bfd_vxlan_bfd_vxlan_num_entry(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        bfd_vxlan = ET.SubElement(kap_custom_profile, "bfd-vxlan")
        bfd_vxlan_num_entry = ET.SubElement(bfd_vxlan, "bfd_vxlan_num_entry")
        bfd_vxlan_num_entry.text = kwargs.pop('bfd_vxlan_num_entry')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_bfd_l3_bfd_l3_hello_interval(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        bfd_l3 = ET.SubElement(kap_custom_profile, "bfd-l3")
        bfd_l3_hello_interval = ET.SubElement(bfd_l3, "bfd_l3_hello_interval")
        bfd_l3_hello_interval.text = kwargs.pop('bfd_l3_hello_interval')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_bfd_l3_bfd_l3_num_entry(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        bfd_l3 = ET.SubElement(kap_custom_profile, "bfd-l3")
        bfd_l3_num_entry = ET.SubElement(bfd_l3, "bfd_l3_num_entry")
        bfd_l3_num_entry.text = kwargs.pop('bfd_l3_num_entry')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_fcoe_fcoe_hello_interval(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        fcoe = ET.SubElement(kap_custom_profile, "fcoe")
        fcoe_hello_interval = ET.SubElement(fcoe, "fcoe_hello_interval")
        fcoe_hello_interval.text = kwargs.pop('fcoe_hello_interval')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_custom_profile_kap_custom_profile_fcoe_fcoe_num_entry(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        custom_profile = ET.SubElement(hardware, "custom-profile")
        kap_custom_profile = ET.SubElement(custom_profile, "kap-custom-profile")
        name_key = ET.SubElement(kap_custom_profile, "name")
        name_key.text = kwargs.pop('name')
        fcoe = ET.SubElement(kap_custom_profile, "fcoe")
        fcoe_num_entry = ET.SubElement(fcoe, "fcoe_num_entry")
        fcoe_num_entry.text = kwargs.pop('fcoe_num_entry')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_flexports_output_flexport_list_port_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_flexports = ET.Element("get_flexports")
        config = get_flexports
        output = ET.SubElement(get_flexports, "output")
        flexport_list = ET.SubElement(output, "flexport-list")
        port_id = ET.SubElement(flexport_list, "port-id")
        port_id.text = kwargs.pop('port_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        